﻿<#
.NOTES
None
.DESCRIPTION
Automate teardown and redeployment of vApp for a classroom environment through the EMBOTICS vCommander REST API. Tested against vCommander Rest Client version 2.5


.EXAMPLE
.\Vapp_Automation.ps1 -vCommanderServer 'bullet.pv.embotics.com' -VappName 'UbuntuVapp' -vCredFile 'c:\scripts\superuser.xml' -LogfileLocation 'C:\scripts\VappAutomation.log'
#>

<#
[CmdletBinding()]
	param(
        [Parameter(Mandatory=$True)]
        [string] $vCommanderServer = $(Throw "Provide the FQDN of the VcommanderServer."), 
        [String] $VappName = $(Throw "Provide the Name of the vAPP being automated"),
		[string] $vCredFile = $(Throw "Please provide the Path to the encrypted .xml Credential for vCommander")
        [string] $LogfileLocation = $(Throw "Please a log file location")
        )
#>     

#Log to Disk
    Start-Transcript -path $LogfileLocation

#Remove and re-add the modules 
    Write-Host "Loading Modules"
    $moduleName = "VCommanderRestClient"

    If (-not (Get-Module -name $moduleName)) {
                    Import-Module -Name $moduleName 
    } else {
                    Remove-Module $moduleName
                    Import-Module -Name $moduleName 
    }

    $moduleName = "VCommander"
    If (-not (Get-Module -name $moduleName)) {
                    Import-Module -Name $moduleName 
    } else {
                    Remove-Module $moduleName
                    Import-Module -Name $moduleName 
    }

#Connect to vCommander
    $Global:SERVICE_HOST = $vCommanderServer
    $Global:REQUEST_HEADERS =@{}
    $Global:BASE_SERVICE_URI = $Global:BASE_SERVICE_URI_PATTERN.Replace("{service_host}",$Global:SERVICE_HOST)   
	$cred = (New-DecryptCredential -keyFilePath $VCredFile) 	
    $Global:CREDENTIAL = $cred
    VCommander\Set-IgnoreSslErrors
    Connect-Client

#####Check if Vapp exists
            try
            {
                #Check and see if $ListVapps = null
                $ListvApps = $(Get-VApps -max 1000 ).VirtualAppCollection.VirtualApps | Where displayname -eq $VappName
            }
            catch
            {
                #catching the Exception
                write-host "Caught an exception:" -ForegroundColor Red
                write-host "Exception Type: $($_.Exception.GetType().FullName)" -ForegroundColor Red
                write-host "Exception Message: $($_.Exception.Message)" -ForegroundColor Red
            }
            finally
{
    write-host "Continue with script"
}
if ($ListvApps){
        $VappState = $ListvApps.state
        if ($VappState -like 'ON')
            { 
            Remove-vApp $ListvApps.id
            } 
        Start-Sleep -seconds 500
        Write-Host "The vApp $VappName was deleted, running re-deployment commands" 
        #Request the Service
        $existingPS = Get-PublishedServiceByName -name "$VappName"
        $requestParams = Get-PSRequestParams -psId $existingPS.PublishedService.id    
        $result = New-ServiceRequest -psId $existingPS.PublishedService.id -requestParams $requestParams
        Write-Host "New Service Request $VappName Submitted"
    }
    Else{
        Write-Host "The vApp $VappName Does not currently exist, nothing to delete running deployment commands" 
        Start-Sleep -seconds 30
        $existingPS = Get-PublishedServiceByName -name "$VappName"
        $requestParams = Get-PSRequestParams -psId $existingPS.PublishedService.id    
        $result = New-ServiceRequest -psId $existingPS.PublishedService.id -requestParams $requestParams
        Write-Host "New Service Request $VappName Submitted"
    }
Stop-Transcript